module Squarespace
  module Sync
    class Cli < Thor
      include Thor::Actions

      desc "version", "Show the version"
      def version
        say Squarespace::Sync::VERSION
      end

      desc "setup", "Sets up squarespace.yaml for configuring your account"
      def setup
        output_file = File.join(Squarespace::Sync.local_path, "squarespace.yaml")
        template_file = "squarespace.tt"
        options = {
          host: "dev.squarespace.com",
          username: "you@example.com",
          password: "\"\"",
          directory: "your-site",
          port: 2030,
          ignore: %w{.gitignore Gemfile Gemfile.lock}
        }
        template( template_file, output_file, options )
      end

      desc "push FILE", "Push files to Squarespace"
      def push(file=nil)
        Connection.new do |sftp, options, instance|
          if file
            local_file = File.join(Squarespace::Sync.local_path, file)
            instance.push_file( sftp, local_file, File.join(options[:directory], file) )
          else
            instance.push_tree( sftp, options[:directory] )
          end
        end
      end

      desc "pull FILE", "Pull files from Squarespace"
      def pull(file=nil)
        Connection.new do |sftp, options, instance|
          if file
            local_file = File.join(Squarespace::Sync.local_path, file)
            instance.pull_file( sftp, File.join(options[:directory], file), local_file )
          else
            instance.pull_tree( sftp, options[:directory] )
          end
        end
      end

      def self.source_root
        File.dirname(__FILE__)
      end
    end
  end
end